# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

# An enumeration indicating which entities should match a SceneEntityDeletion command
class SceneEntityDeletionType(object):
    # Delete the existing entity on the same topic that has the provided `id`
    MATCHING_ID = 0
    # Delete all existing entities on the same topic
    ALL = 1
