# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

# Numeric type
class NumericType(object):
    UNKNOWN = 0
    UINT8 = 1
    INT8 = 2
    UINT16 = 3
    INT16 = 4
    UINT32 = 5
    INT32 = 6
    FLOAT32 = 7
    FLOAT64 = 8
