# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

# An array of FrameTransform messages
class FrameTransforms(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = FrameTransforms()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsFrameTransforms(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # FrameTransforms
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # Array of transforms
    # FrameTransforms
    def Transforms(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            x = self._tab.Vector(o)
            x += flatbuffers.number_types.UOffsetTFlags.py_type(j) * 4
            x = self._tab.Indirect(x)
            from .FrameTransform import FrameTransform
            obj = FrameTransform()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # FrameTransforms
    def TransformsLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # FrameTransforms
    def TransformsIsNone(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        return o == 0

def FrameTransformsStart(builder): builder.StartObject(1)
def Start(builder):
    return FrameTransformsStart(builder)
def FrameTransformsAddTransforms(builder, transforms): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(transforms), 0)
def AddTransforms(builder, transforms):
    return FrameTransformsAddTransforms(builder, transforms)
def FrameTransformsStartTransformsVector(builder, numElems): return builder.StartVector(4, numElems, 4)
def StartTransformsVector(builder, numElems):
    return FrameTransformsStartTransformsVector(builder, numElems)
def FrameTransformsEnd(builder): return builder.EndObject()
def End(builder):
    return FrameTransformsEnd(builder)