# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

# Log level
class LogLevel(object):
    UNKNOWN = 0
    DEBUG = 1
    INFO = 2
    WARNING = 3
    ERROR = 4
    FATAL = 5
