# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

# Type of position covariance
class PositionCovarianceType(object):
    UNKNOWN = 0
    APPROXIMATED = 1
    DIAGONAL_KNOWN = 2
    KNOWN = 3
